import time
import bluetooth
import numpy

import busio
import board
import adafruit_amg88xx


"""
Format raw sensor data as string
Accepts sensor data in form of nested list
"""
def format_sensor_data(data):
    # flatten nested list of pixel values
    # convert each value from float to string
    flat_data = [str(value) for sublist in data for value in sublist]

    # build string using join() with "|" as separators
    string_data = "|".join(flat_data)

    return string_data


"""
Main function
"""
def main():
    # initialize I2C connection interface
    i2c = busio.I2C(board.SCL, board.SDA)
    # setup connection to AMG8833 using I2C
    amg = adafruit_amg88xx.AMG88XX(i2c)

    # create Bluetooth server socket
    server_sock = bluetooth.BluetoothSocket(bluetooth.RFCOMM)
    # bind server socket to a port
    server_sock.bind(("", bluetooth.PORT_ANY))
    # listen on port
    server_sock.listen(1)

    # get port
    port = server_sock.getsockname()[1]
    print("Listening to connections on RFCOMM channel", port)

    # continuously wait for client connections
    while True:
        # establish connection
        # blocking call
        client_sock, client_info = server_sock.accept()
        print("Accepted connection from", client_info)

        # start communication
        try:
            while True:
                sensor_data = format_sensor_data(amg.pixels)
                # print(sensor_data)
                client_sock.send(sensor_data)

                # delay
                time.sleep(0.5)
        except OSError:
            print("Client socket closed")
            pass

        # close client socket
        client_sock.close()

    # close server socket
    server_sock.close()


if __name__ == "__main__":
    main()